@@ -1,4 +1,3 @@
-
 from pypresence import Presence
 import time
 
@@ -13,7 +12,16 @@ RPC = Presence(client_id=client_id)
 RPC.connect()
 
 
-RPC.update(state="Custom gifs",details="Using pypresence",large_image=("https://media.tenor.com/9c83g4VPctQAAAAi/shaking-eyes-eyes-shaking.gif"), large_text="Watching!",
-            small_image=("https://media.giphy.com/media/4UjV5LeD66EPruSG18/giphy.gif"), small_text="Spinning")
+RPC.update(
+    state="Custom gifs",
+    details="Using pypresence",
+    large_image=(
+        "https://media.tenor.com/9c83g4VPctQAAAAi/shaking-eyes-eyes-shaking.gif"
+    ),
+    large_text="Watching!",
+    small_image=("https://media.giphy.com/media/4UjV5LeD66EPruSG18/giphy.gif"),
+    small_text="Spinning",
+)
+
 while True:
     time.sleep(1)
