@@ -2,7 +2,7 @@ from pypresence import Presence
 import time
 import random
 
-client_id = '64567352374564'  # Put your Client ID here, this is a fake ID
+client_id = "64567352374564"  # Put your Client ID here, this is a fake ID
 RPC = Presence(client_id)  # Initialize the Presence class
 RPC.connect()  # Start the handshake loop
 
@@ -17,10 +17,12 @@ quotes = [
     "Life is what happens to you while you’re busy making other plans.",
     "Strive not to be a success, but rather to be of value.",
     "The best time to plant a tree was 20 years ago. The second best time is now.",
-    "Everything you’ve ever wanted is on the other side of fear."
+    "Everything you’ve ever wanted is on the other side of fear.",
 ]  # The quotes to choose from
 
 
 while True:  # The presence will stay on as long as the program is running
-    RPC.update(details="Famous Quote:", state=random.choice(quotes)) #Set the presence, picking a random quote
-    time.sleep(60) #Wait a wee bit
+    RPC.update(
+        details="Famous Quote:", state=random.choice(quotes)
+    )  # Set the presence, picking a random quote
+    time.sleep(60)  # Wait a wee bit
